/*
 * C
 *
 * Copyright 2018-2023 MicroEJ Corp. All rights reserved.
 * Use of this source code is governed by a BSD-style license that can be found with this software.
 */

/**
 * @file
 * @brief LLGPIO implementation.
 * @author MicroEJ Developer Team
 * @version 1.0.1
 * @date 3 May 2018
 */

#include <stdint.h>
#include <stdio.h>
#include "sni.h"
#include "hal_stm32.h"
#include "LLGPIO_impl.h"
#include "FreeRTOS.h"
#include "task.h"

#ifdef __cplusplus
	extern "C" {
#endif

static uint8_t LLGPIO_get_callback(int32_t pin);
void reader_function(void * pvParameters);

static uint8_t GPIO_initialized = 0;

static void LLGPIO_initialize(void)
{
    if(!GPIO_initialized)
		{
			GPIO_initialized = 1;
			__GPIOI_CLK_ENABLE();
			GPIO_InitTypeDef GPIO_InitStruct;

			/* Configure LED pin as output */
			GPIO_InitStruct.Mode = GPIO_MODE_OUTPUT_PP;
			GPIO_InitStruct.Pull = GPIO_NOPULL;
			GPIO_InitStruct.Speed = GPIO_SPEED_LOW;
			GPIO_InitStruct.Pin = GPIO_PIN_1;

			HAL_GPIO_Init(GPIOI, &GPIO_InitStruct);
		}
}

void LLGPIO_set(jint pin, jboolean state)
{	 
    GPIO_PinState value;
    LLGPIO_initialize();

	if(state == JFALSE)
	{
		value = GPIO_PIN_RESET;
	}
    else
	{
    	value = GPIO_PIN_SET;
	}

    HAL_GPIO_WritePin(GPIOI, GPIO_PIN_1, value);
}

jboolean LLGPIO_get(jint pin)
{
    LLGPIO_initialize();
    GPIO_PinState state = HAL_GPIO_ReadPin(GPIOI, GPIO_PIN_1);
    return (state == GPIO_PIN_RESET ? JFALSE : JTRUE);

}

#ifdef __cplusplus
	}
#endif
